@@ -13,7 +13,21 @@ from .SReLU import SReLU
 class StochasticActivation(torch.nn.Module):
     def __init__(self):
         super().__init__()
-        self.gate = random.choice([APLU, GALU, SmallGALU, MELU, WideMELU, PDELU, SReLU])
+        self.gate = random.choice(
+            [
+                APLU,
+                GALU,
+                SmallGALU,
+                MELU,
+                WideMELU,
+                PDELU,
+                SReLU,
+                torch.nn.ReLU,
+                torch.nn.PReLU,
+                torch.nn.LeakyReLU,
+                torch.nn.ELU,
+            ]
+        )
         self.gate = self.gate()
 
     def forward(self, x: torch.Tensor) -> torch.Tensor:
